@@ -9,7 +9,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/b.c,v 1.35 2018/01/08 02:01:18 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/b.c,v 1.40 2018/11/11 18:15:37 tg Exp $");
 
 #include <unistd.h>
 #include <sys/stat.h>
@@ -55,6 +55,8 @@ int error;
 int force = 0;
 VFILE *vmem;
 
+static int brch_u8(P *);
+
 const unsigned char *msgs[] = {
 	UC "No error",
 	UC "New File",
@@ -557,108 +559,75 @@ int pgetb(P *p)
 	} else {
 		p->valcol = 0;
 	}
-	return c;
+	return (int)((unsigned int)c);
 }
 
-/* return current character and move p to the next character.  column will be updated if it was valid. */
-int pgetc(P *p)
+/*
+ * return current character and move p to the next character.
+ * column will be updated if it was valid.
+ */
+int
+pgetc(P *p)
 {
+	int c, b, w, valcol;
+
+	/* remember whether column number was valid */
+	valcol = p->valcol;
+
+	/* get first byte */
+	if ((b = pgetb(p)) == NO_MORE_DATA)
+		return (b);
+
 	if (p->b->o.charmap->type) {
-		int val, c, n, wid;
-		/* int m, oc; */
+		struct utf8_sm utf8_sm;
 
-		val = p->valcol;	/* Remember if column number was valid */
-		c = pgetb(p);		/* Get first byte */
-		/* oc = c; */
-
-		if (c==NO_MORE_DATA)
-			return c;
-
-		if ((c&0xE0)==0xC0) { /* Two bytes */
-			n = 1;
-			c &= 0x1F;
-		} else if ((c&0xF0)==0xE0) { /* Three bytes */
-			n = 2;
-			c &= 0x0F;
-		} else if ((c&0xF8)==0xF0) { /* Four bytes */
-			n = 3;
-			c &= 0x07;
-		} else if ((c&0xFC)==0xF8) { /* Five bytes */
-			n = 4;
-			c &= 0x03;
-		} else if ((c&0xFE)==0xFC) { /* Six bytes */
-			n = 5;
-			c &= 0x01;
-		} else if ((c&0x80)==0x00) { /* One byte */
-			n = 0;
-		} else { /* 128-191, 254, 255: Not a valid UTF-8 start character */
-			n = 0;
-			c = 0x1000FFFE;
-			/* c -= 384; */
-		}
-
-		/* m = n; */
-
-		if (n) {
-			int d;
-
-			do {
-				d = brc(p);
-				if (d == NO_MORE_DATA || (d&0xC0)!=0x80)
-					break;
+		utf8_init(&utf8_sm);
+ decode:
+		switch ((c = utf8_decode(&utf8_sm, b))) {
+		case -1:
+			if ((b = brc(p)) != NO_MORE_DATA &&
+			    /* due to pgetb() interpreting control chars */
+			    (b & 0x80)) {
 				pgetb(p);
-				c = ((c<<6)|(d&0x3F));
-			} while (--n);
-			if (n) { /* FIXME: there was a bad UTF-8 sequence */
-				/* How to represent this? */
-				/* pbkwd(p,m-n);
-				c = oc - 384; */
-				c = d == NO_MORE_DATA ? 0x1000FFFF : 0x1000FFFE;
-				wid = 1;
-			} else if (val)
-				wid = joe_wcwidth(c);
-		} else {
-			wid = 1;
+				goto decode;
+			}
+			--utf8_sm.ptr;
+			/* FALLTHROUGH */
+		case -2:
+			pbkwd(p, utf8_sm.ptr);
+			c = 0x80000000 | (int)((unsigned int)utf8_sm.buf[0]);
+			w = 1;
+			break;
+		case -3:
+			c = 0x80000000 | b;
+			w = 1;
+			break;
+		default:
+			w = joe_wcwidth(c);
+			break;
 		}
-
-		if (val) { /* Update column no. if it was valid to start with */
-			p->valcol = 1;
-			if (c=='\t')
-				p->col += (p->b->o.tab) - (p->col) % (p->b->o.tab);
-			else if (c=='\n')
-				p->col = 0;
-			else
-				p->col += wid;
-		}
-
-		return c;
 	} else {
-		unsigned char c;
-
-		if (p->ofst == GSIZE(p->hdr))
-			return NO_MORE_DATA;
-		c = GCHAR(p);
-		if (++p->ofst == GSIZE(p->hdr))
-			pnext(p);
-		++p->byte;
-
-		if (c == '\n') {
-			++(p->line);
-			p->col = 0;
-			p->valcol = 1;
-		} else if (p->b->o.crlf && c == '\r') {
-			if (brc(p) == '\n')
-				return pgetc(p);
-			else
-				++p->col;
-		} else {
-			if (c == '\t')
-				p->col += (p->b->o.tab) - (p->col) % (p->b->o.tab);
-			else
-				++(p->col);
-		}
-		return c;
+		c = b;
+		w = 1;
 	}
+
+	/* update column number if it was valid to start with */
+	if (valcol) {
+		p->valcol = 1;
+		switch (c) {
+		case '\t':
+			p->col += p->b->o.tab - p->col % p->b->o.tab;
+			break;
+		case '\n':
+			p->col = 0;
+			break;
+		default:
+			p->col += w;
+			break;
+		}
+	}
+
+	return (c);
 }
 
 /* move p n characters forward */
@@ -722,73 +691,25 @@ int prgetb(P *p)
 }
 
 /* move p to the previous character (try to keep col updated) */
-int prgetc(P *p)
+int
+prgetc(P *p)
 {
-	if (p->b->o.charmap->type) {
+	P *q, *r;
 
-		if (pisbol(p))
-			return prgetb(p);
-		else {
-			P *q = pdup(p);
-			P *r;
-			p_goto_bol(q);
-			r = pdup(q);
-			while (q->byte<p->byte) {
-				pset(r, q);
-				pgetc(q);
-			}
-			pset(p,r);
-			prm(r);
-			prm(q);
-			return brch(p);
-		}
+	if (!p->b->o.charmap->type || pisbol(p))
+		return (prgetb(p));
 
-#if 0
-		int d = 0;
-		int c;
-		int n = 0;
-		int val = p->valcol;
-		for(;;) {
-			c = prgetb(p);
-			if (c == NO_MORE_DATA)
-				return NO_MORE_DATA;
-			else if ((c&0xC0)==0x80) {
-				d |= ((c&0x3F)<<n);
-				n += 6;
-			} else if ((c&0x80)==0x00) { /* One char */
-				d = c;
-				break;
-			} else if ((c&0xE0)==0xC0) { /* Two chars */
-				d |= ((c&0x1F)<<n);
-				break;
-			} else if ((c&0xF0)==0xE0) { /* Three chars */
-				d |= ((c&0x0F)<<n);
-				break;
-			} else if ((c&0xF8)==0xF0) { /* Four chars */
-				d |= ((c&0x07)<<n);
-				break;
-			} else if ((c&0xFC)==0xF8) { /* Five chars */
-				d |= ((c&0x03)<<n);
-				break;
-			} else if ((c&0xFE)==0xFC) { /* Six chars */
-				d |= ((c&0x01)<<n);
-				break;
-			} else { /* FIXME: Invalid (0xFE or 0xFF found) */
-				break;
-			}
-		}
-
-		if (val && c!='\t' && c!='\n') {
-			p->valcol = 1;
-			p->col -= joe_wcwidth(d);
-		}
-
-		return d;
-#endif
-	}
-	else {
-		return prgetb(p);
+	q = pdup(p);
+	p_goto_bol(q);
+	r = pdup(q);
+	while (q->byte < p->byte) {
+		pset(r, q);
+		pgetc(q);
 	}
+	pset(p, r);
+	prm(r);
+	prm(q);
+	return (brch_u8(p));
 }
 
 /* move p n characters backwards */
@@ -970,7 +891,7 @@ P *pcol(P *p, long goalcol)
 			int c;
 			int wid;
 
-			c = brch(p);
+			c = brch_u8(p);
 
 			if (c == NO_MORE_DATA)
 				break;
@@ -2124,10 +2045,8 @@ bload(const unsigned char *s)
 		fi = fopen((char *)n, "r");
 		if (!fi)
 			nowrite = 0;
-		if (fi) {
-			fstat(fileno(fi),&sbuf);
+		else if (!fstat(fileno(fi), &sbuf))
 			mod_time = sbuf.st_mtime;
-		}
 	}
 #if HAVE_BACKSLASH_PATHS
 	joesep(n);
@@ -2419,12 +2338,14 @@ int bsavefd(P *p, int fd, long int size)
  * same name as buffer or is about to get this name).
  */
 
-int bsave(P *p, unsigned char *s, long int size, int flag)
+int
+bsave(P *p, unsigned char *s, long int size, int flag)
 {
 	FILE *f;
 	long skip, amnt;
 	struct stat sbuf;
 	int norm = 0;
+	char closemethod;
 
 	s = parsens(s, &skip, &amnt);
 
@@ -2435,17 +2356,22 @@ int bsave(P *p, unsigned char *s, long int size, int flag)
 		nescape(maint->t);
 		ttclsn();
 		f = popen((char *)(s + 1), "w");
-	} else if (s[0] == '>' && s[1] == '>')
+		closemethod = 2;
+	} else if (s[0] == '>' && s[1] == '>') {
 		f = fopen((char *)(s + 2), "a");
-	else if (!strcmp(s, "-")) {
+		closemethod = 1;
+	} else if (!strcmp(s, "-")) {
 		nescape(maint->t);
 		ttclsn();
 		f = stdout;
-	} else if (skip || amnt != LONG_MAX)
+		closemethod = 3;
+	} else if (skip || amnt != LONG_MAX) {
 		f = fopen((char *)s, "r+");
-	else {
+		closemethod = 1;
+	} else {
 		f = fopen((char *)s, "w");
 		norm = 1;
+		closemethod = 1;
 	}
 #if HAVE_BACKSLASH_PATHS
 	joesep(s);
@@ -2475,12 +2401,18 @@ int bsave(P *p, unsigned char *s, long int size, int flag)
 	}
 
  err:
-	if (s[0] == '!')
-		pclose(f);
-	else if (strcmp(s, "-"))
+	switch (closemethod) {
+	case 1:
 		fclose(f);
-	else
+		break;
+	case 2:
+		pclose(f);
+		break;
+	case 3:
+		/* do not close stdout */
 		fflush(f);
+		break;
+	}
 
 	/* Update orignal date of file */
 	/* If it's not named, it's about to be */
@@ -2503,21 +2435,24 @@ int brc(P *p)
 {
 	if (p->ofst == GSIZE(p->hdr))
 		return NO_MORE_DATA;
-	return GCHAR(p);
+	return ((int)((unsigned int)(unsigned char)GCHAR(p)));
 }
 
 /* Return character at p */
 
-int brch(P *p)
+int
+brch(P *p)
 {
-	if (p->b->o.charmap->type) {
-		P *q = pdup(p);
-		int c = pgetc(q);
-		prm(q);
-		return c;
-	} else {
-		return brc(p);
-	}
+	return (p->b->o.charmap->type ? brch_u8(p) : brc(p));
+}
+
+static int
+brch_u8(P *p)
+{
+	P *q = pdup(p);
+	int c = pgetc(q);
+	prm(q);
+	return (c);
 }
 
 unsigned char *brmem(P *p, unsigned char *blk, int size)
