@@ -11,7 +11,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/builtins.c,v 1.31 2018/03/15 23:28:56 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/builtins.c,v 1.32 2018/10/20 16:25:47 tg Exp $");
 
 #ifndef JUPPRC_BUILTIN_NAME
 #define JUPPRC_BUILTIN_NAME "jupprc"
@@ -49,6 +49,12 @@ const unsigned char * const builtins[] = {
 		"-tab 8\n"
 		"--wordwrap\n"
 		"\n"
+		"*.bin\n"
+		"--crlf\n"
+		"--guess_crlf\n"
+		"-encoding ascii\n"
+		"-hex\n"
+		"\n"
 		"*.py\n"
 		"-encoding utf8\n"
 		"-tab 4\n"
@@ -164,7 +170,7 @@ const unsigned char * const builtins[] = {
 		"\\i \\i go to \\uhttp://sf.net/projects/joe-editor/\\u for upstream bug reports. JUPP 2.8 \\i \\i\n"
 		"\\i \\i for DOS compiled by A. Totlis, packed with LHarc 2.13; JUPP 3.x for UNIX\\d(R)\\d \\i \\i\n"
 		"\\i \\i at \\uhttp://mirbsd.de/jupp\\u and by \\bThorsten \"\\dmirabilos\\d\" Glaser <\\utg@mirbsd.org\\u>\\b \\i \\i\n"
-		"\\i \\i @(#) blt_in 2018-03-15; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
+		"\\i \\i @(#) blt_in 2018-10-20; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
 		"}\n"
 		"\n"
 		"{CharTable\n"
@@ -259,21 +265,21 @@ const unsigned char * const builtins[] = {
 		":def dorepl setmark,\":\",qrepl\n"
 		":def pastemain helpcard,\"Paste\",rtn,keymap,\"Paste\",rtn\n"
 		":def conflictmarker dosrch,\"\\\\^\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[<>=]\\\\[ \\\\n]\",rtn,rtn,ltarw\n"
-		":def fixwhitespace setmark,\":\",eof,\" \",bof,\"a\",qrepl,\"\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\+\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\$\",rtn,rtn,rtn,\"r\",eof,rtn,ffirst,\"\\\\^\\\\[^\\\\n]\",rtn,\"b\",rtn,eol,markb,bof,delch,eof,markk,blkdel,ffirst,\"\\\\?\",rtn,\"b\",rtn,eol,rtn,gomark,\":\",eof\n"
-		":def freedroidz splitw,prevw,scratch,\"nbc-Output\",rtn,nextw,save,markk,bol,markb,prevw,prevw,blkcpy,nextw,nextw,rtn,prevw,eol,\"'\",bol,qrepl,\"'\",rtn,rtn,\"'\\\\\\\\''\",rtn,\"r\",backs,backs,backs,bol,\"LC_ALL=C; export LC_ALL; fn='\",eol,\"; p=--posix; sed $p -e q </dev/null >/dev/null 2>&1 || p=; r=$(sed $p -e 's[^^][&]g; s\\\\^\\\\\\\\^g' <<EOF\",rtn,\"$fn\",rtn,\"EOF\",rtn,\"); (case $fn in *.nxc) ;; *) echo '==> Error: filename not *.nxc'; exit ;; esac; echo \\\"Compiling $fn\\\"; nbc -sm- -d \\\"$fn\\\" 2>&1; x=$?; if test $x = 0; then echo '==> OK'; else echo '==> Error code:' $x; fi) | tr '\\\\n' '' | sed $p -e 's!# *\\\\([^]*\\\\)File \\\"[^\\\"]*/\\\\('\\\"$r\\\"'\\\\)\\\" ; line \\\\([0-9]*\\\\)!\\\\2:\\\\3: \\\\1!g' -e 's!#\\\\([^]*\\\\)File \\\"\\\\([^\\\"]*\\\\)\\\" ; line \\\\([0-9]*\\\\)!\\\\2:\\\\3: \\\\1!g' | tr '' '\\\\n'\",rtn,nmark,filt,\"sh\",rtn,rtn,\"Press ^KQ to close this window!\",rtn,parserr\n"
+		":def fixwhitespace psh,setmark,\":\",eof,\" \",bof,\"a\",qrepl,\"\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\+\\\\[\",quote,\"i\",quote,\"k\",quote,\"l\",quote,\"m ]\\\\$\",rtn,rtn,rtn,\"r\",eof,rtn,ffirst,\"\\\\^\\\\[^\\\\n]\",rtn,\"b\",rtn,eol,markb,bof,delch,eof,markk,blkdel,ffirst,\"\\\\?\",rtn,\"b\",rtn,eol,rtn,gomark,\":\",eof\n"
+		":def freedroidz psh,splitw,prevw,scratch,\"nbc-Output\",rtn,nextw,save,markk,bol,markb,prevw,prevw,blkcpy,nextw,nextw,rtn,prevw,eol,\"'\",bol,qrepl,\"'\",rtn,rtn,\"'\\\\\\\\''\",rtn,\"r\",backs,backs,backs,bol,\"LC_ALL=C; export LC_ALL; fn='\",eol,\"; p=--posix; sed $p -e q </dev/null >/dev/null 2>&1 || p=; r=$(sed $p -e 's[^^][&]g; s\\\\^\\\\\\\\^g' <<EOF\",rtn,\"$fn\",rtn,\"EOF\",rtn,\"); (case $fn in *.nxc) ;; *) echo '==> Error: filename not *.nxc'; exit ;; esac; echo \\\"Compiling $fn\\\"; nbc -sm- -d \\\"$fn\\\" 2>&1; x=$?; if test $x = 0; then echo '==> OK'; else echo '==> Error code:' $x; fi) | tr '\\\\n' '' | sed $p -e 's!# *\\\\([^]*\\\\)File \\\"[^\\\"]*/\\\\('\\\"$r\\\"'\\\\)\\\" ; line \\\\([0-9]*\\\\)!\\\\2:\\\\3: \\\\1!g' -e 's!#\\\\([^]*\\\\)File \\\"\\\\([^\\\"]*\\\\)\\\" ; line \\\\([0-9]*\\\\)!\\\\2:\\\\3: \\\\1!g' | tr '' '\\\\n'\",rtn,nmark,filt,\"sh\",rtn,rtn,\"Press ^KQ to close this window!\",rtn,parserr\n"
 		":def docompile edit,rtn,filt,query,parserr\n"
 		":def filtall nmark,filt,uparw\n"
 		":def pvsrch prevpos,gomark,\":\"\n"
 		":def inscurdate insf,\"!date '+%Y-%m-%d'\",rtn,eol,delch\n"
 		":def inscurtime insf,\"!date '+%H:%M:%S'\",rtn,eol,delch\n"
-		"begin_marking,uparw,toggle_marking	^[ [ 1 ; 2 A\n"
-		"begin_marking,dnarw,toggle_marking	^[ [ 1 ; 2 B\n"
-		"begin_marking,rtarw,toggle_marking	^[ [ 1 ; 2 C\n"
-		"begin_marking,ltarw,toggle_marking	^[ [ 1 ; 2 D\n"
-		"begin_marking,bol,toggle_marking	^[ [ 1 ; 2 H\n"
-		"begin_marking,eol,toggle_marking	^[ [ 1 ; 2 F\n"
-		"begin_marking,bof,toggle_marking	^[ [ 1 ; 6 H\n"
-		"begin_marking,eof,toggle_marking	^[ [ 1 ; 6 F\n"
+		"setmark,\":\",uparw,gomark,\":\",begin_marking,uparw,toggle_marking	^[ [ 1 ; 2 A\n"
+		"setmark,\":\",dnarw,gomark,\":\",begin_marking,dnarw,toggle_marking	^[ [ 1 ; 2 B\n"
+		"setmark,\":\",rtarw,gomark,\":\",begin_marking,rtarw,toggle_marking	^[ [ 1 ; 2 C\n"
+		"setmark,\":\",ltarw,gomark,\":\",begin_marking,ltarw,toggle_marking	^[ [ 1 ; 2 D\n"
+		"setmark,\":\",bol,gomark,\":\",begin_marking,bol,toggle_marking	^[ [ 1 ; 2 H\n"
+		"setmark,\":\",eol,gomark,\":\",begin_marking,eol,toggle_marking	^[ [ 1 ; 2 F\n"
+		"setmark,\":\",bof,gomark,\":\",begin_marking,bof,toggle_marking	^[ [ 1 ; 6 H\n"
+		"setmark,\":\",eof,gomark,\":\",begin_marking,eof,toggle_marking	^[ [ 1 ; 6 F\n"
 		"pastemain	^[ P\n"
 		"pastemain	^[ p\n"
 		"pastemain	^[ [ 2 0 0 ~\n"
