@@ -1,5 +1,4 @@
-/* $MirOS: contrib/code/jupp/path.c,v 1.12 2016/10/29 23:44:45 tg Exp $ */
-/* 
+/*
  *	Directory and path functions
  *	Copyright
  *		(C) 1992 Joseph H. Allen
@@ -9,23 +8,16 @@
 #include "config.h"
 #include "types.h"
 
-#include <stdio.h>
-#include <sys/types.h>
-#ifdef HAVE_SYS_STAT_H
+__RCSID("$MirOS: contrib/code/jupp/path.c,v 1.23 2018/01/07 20:32:46 tg Exp $");
+
 #include <sys/stat.h>
-#endif
 #include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
 #ifdef HAVE_PATHS_H
 #  include <paths.h>	/* for _PATH_TMP */
 #endif
-#ifdef HAVE_LIMITS_H
-#include <limits.h>
-#endif
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
 
 #ifdef HAVE_BSD_STRING_H
 #include <bsd/string.h>
@@ -76,23 +68,22 @@
 
 #if HAVE_DRIVE_LETTERS
 #define do_if_drive_letter(path, command) do {		\
-	if ((path)[1] == ':' && (			\
-	    ((path)[0] >= 'a' && (path)[0] <= 'z') ||	\
-	    ((path)[0] >= 'A' && (path)[0] <= 'Z'))) {	\
-		command;				\
+	if ((path)[1] == ':') {				\
+		drvltrhlprv = (path)[0] | 0x20;		\
+		if (drvltrhlprv >= 'a' &&		\
+		    drvltrhlprv <= 'z')			\
+			command;			\
 	}						\
 } while (/* CONSTCOND */ 0)
+#define drvltrhlpr unsigned char drvltrhlprv
 #else
 #define do_if_drive_letter(path, command) do { } while (/* CONSTCOND */ 0)
+#define drvltrhlpr /* nothing */
 #endif
 #define skip_drive_letter(path)	do_if_drive_letter((path), (path) += 2)
 
-#ifndef		_PATH_TMP
-#  ifdef __MSDOS__
-#    define	_PATH_TMP	""
-#  else
-#    define	_PATH_TMP	"/tmp/"
-#  endif
+#ifndef _PATH_TMP
+#define _PATH_TMP	"/tmp/"
 #endif
 
 #if !defined(PATH_MAX) && !defined(HAVE_GET_CURRENT_DIR_NAME)
@@ -116,6 +107,7 @@ unsigned char *joesep(unsigned char *path)
 unsigned char *namprt(unsigned char *path)
 {
 	unsigned char *z;
+	drvltrhlpr;
 
 	skip_drive_letter(path);
 	z = path + slen(path);
@@ -127,6 +119,7 @@ unsigned char *namprt(unsigned char *path)
 unsigned char *namepart(unsigned char *tmp, unsigned char *path)
 {
 	unsigned char *z;
+	drvltrhlpr;
 
 	skip_drive_letter(path);
 	z = path + strlen((char *)path);
@@ -140,6 +133,7 @@ unsigned char *dirprt_ptr(unsigned char *path)
 {
 	unsigned char *b = path;
 	unsigned char *z = path + slen(path);
+	drvltrhlpr;
 
 	skip_drive_letter(b);
 	while ((z != b) && (z[-1] != '/'))
@@ -155,6 +149,7 @@ unsigned char *begprt(unsigned char *path)
 {
 	unsigned char *z = path + slen(path);
 	int drv = 0;
+	drvltrhlpr;
 
 	do_if_drive_letter(path, drv = 2);
 	while ((z != path + drv) && (z[-1] == '/'))
@@ -172,6 +167,7 @@ unsigned char *endprt(unsigned char *path)
 {
 	unsigned char *z = path + slen(path);
 	int drv = 0;
+	drvltrhlpr;
 
 	do_if_drive_letter(path, drv = 2);
 	while ((z != path + drv) && (z[-1] == '/'))
@@ -209,7 +205,7 @@ int mkpath(unsigned char *path)
 				return 1;
 		}
 		*s = c;
-	      in:
+ in:
 		while (*s == '/')
 			++s;
 		path = s;
@@ -241,12 +237,19 @@ unsigned char *mktmp(unsigned char *where, int *fdp)
 				   vsrm(); */
 #ifdef HAVE_MKSTEMP
 	joe_snprintf_1((char *)name, namesize, "%s/joe.tmp.XXXXXXXXXX", where);
-	if ((fd = mkstemp((char *)name)) == -1)
-		return (NULL);	/* FIXME: vflsh() and vflshf() */
-				/* expect mktmp() always succeed!!! */
-	fchmod(fd, 0600);	/* Linux glibc 2.0 mkstemp() creates it with */
-				/* 0666 mode --> change it to 0600, so nobody */
-				/* else sees content of temporary file */
+	if ((fd = mkstemp((char *)name)) == -1) {
+		vsrm(name);
+		/*
+		 * FIXME: vflsh() and vflshf()
+		 * expect mktmp() always succeed!
+		 */
+		return (NULL);
+	}
+	/*
+	 * Linux glibc 2.0 mkstemp() creates it with 0666 mode, ergo we
+	 * change it to 0600, so nobody else sees content of temporary file
+	 */
+	fchmod(fd, 0600);
 #else
 #warning "Waah, this is insane! Consider getting mkstemp!"
  loop:
@@ -257,8 +260,11 @@ unsigned char *mktmp(unsigned char *where, int *fdp)
 		close(fd);
 		goto loop;	/* FIXME: possible endless loop --> DoS attack */
 	}
-	if ((fd = open(name, O_RDWR | O_CREAT | O_EXCL, 0600)) == -1)
-		return (NULL);	/* FIXME: see above */
+	if ((fd = open(name, O_RDWR | O_CREAT | O_EXCL, 0600)) == -1) {
+		vsrm(name);
+		/* FIXME: see above */
+		return (NULL);
+	}
 #endif
 	if (fdp)
 		*fdp = fd;
@@ -267,7 +273,7 @@ unsigned char *mktmp(unsigned char *where, int *fdp)
 	return (name);
 }
 /********************************************************************/
-int rmatch(unsigned char *a, unsigned char *b)
+int rmatch(const unsigned char *a, const unsigned char *b)
 {
 	int flag, inv, c;
 
@@ -328,48 +334,7 @@ int isreg(unsigned char *s)
 	return 0;
 }
 /********************************************************************/
-#ifdef __MSDOS__
-#include <dos.h>
-#include <dir.h>
-
-struct direct {
-	unsigned char d_name[16];
-} direc;
-int dirstate = 0;
-struct ffblk ffblk;
-unsigned char *dirpath = NULL;
-
-void *opendir(unsigned char *path)
-{
-	dirstate = 0;
-	return &direc;
-}
-
-void closedir()
-{
-}
-
-struct direct *readdir()
-{
-	int x;
-
-	if (dirstate) {
-		if (findnext(&ffblk))
-			return NULL;
-	} else {
-		if (findfirst("*.*", &ffblk, FA_DIREC))
-			return NULL;
-		dirstate = 1;
-	}
-
-	strcpy(direc.d_name, ffblk.ff_name);
-	for (x = 0; direc.d_name[x]; ++x)
-		direc.d_name[x] = tolower(direc.d_name[x]);
-	return &direc;
-}
-#endif
-/********************************************************************/
-unsigned char **rexpnd(unsigned char *word)
+unsigned char **rexpnd(const unsigned char *word)
 {
 	void *dir;
 	unsigned char **lst = NULL;
@@ -402,34 +367,9 @@ int chJpwd(const unsigned char *path)
 
 int chpwd(const unsigned char *path)
 {
-#ifdef __MSDOS__
-	unsigned char buf[256];
-	int x;
-
-	if (!path)
-		return 0;
-	if ((path[0]) && (path[1] == ':')) {
-		if (_chdrive(path[0] & 0x1F))
-			return -1;
-		path += 2;
-	}
-	if (!path[0])
-		return 0;
-	strcpy(buf, path);
-	x = strlen(buf);
-	while (x > 1) {
-		--x;
-		if ((buf[x] == '/') || (buf[x] == '\\'))
-			buf[x] = 0;
-		else
-			break;
-	}
-	return chdir(buf);
-#else
 	if ((!path) || (!path[0]))
 		return 0;
 	return chdir((char *)path);
-#endif
 }
 
 /* The pwd function */
