@@ -1,8 +1,10 @@
-/* $MirOS: contrib/code/jupp/syntax.h,v 1.3 2016/10/07 19:43:55 tg Exp $ */
-
 #ifndef _Isyntax
 #define _Isyntax 1
 
+#ifdef EXTERN
+__IDSTRING(rcsid_syntax_h, "$MirOS: contrib/code/jupp/syntax.h,v 1.5 2017/12/02 17:00:50 tg Exp $");
+#endif
+
 #include "hash.h"
 
 /*
