@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/uerror.c,v 1.4 2017/08/09 00:46:02 tg Exp $ */
 /*
  *	Compiler error handler
  *	Copyright
@@ -9,13 +8,14 @@
 #include "config.h"
 #include "types.h"
 
-#include <stdio.h>
+__RCSID("$MirOS: contrib/code/jupp/uerror.c,v 1.11 2017/12/07 02:10:18 tg Exp $");
 
 #include "b.h"
 #include "bw.h"
 #include "main.h"
 #include "queue.h"
 #include "tw.h"
+#include "uerror.h"
 #include "ufile.h"
 #include "utils.h"
 #include "vs.h"
@@ -33,7 +33,7 @@ struct error {
 	unsigned char *file;		/* Target file name */
 	long src;		/* Error-file line number */
 	unsigned char *msg;		/* The message */
-} errors = { { &errors, &errors} };
+} errors = { { &errors, &errors}, 0, 0, NULL, 0, NULL };
 ERROR *errptr = &errors;	/* Current error row */
 
 B *errbuf = NULL;		/* Buffer with error messages */
@@ -97,7 +97,7 @@ void saverr(unsigned char *name)
 }
 
 /* Pool of free error nodes */
-ERROR errnodes = { {&errnodes, &errnodes} };
+ERROR errnodes = { {&errnodes, &errnodes}, 0, 0, NULL, 0, NULL };
 
 /* Free an error node */
 
@@ -135,10 +135,11 @@ static int parseit(struct charmap *map,unsigned char *s, long int row)
 
 	do {
 		/* Skip to first word */
-		for (x = y; s[x] && !(joe_isalnum_(map,s[x]) || s[x] == '.' || s[x] == '/'); ++x) ;
+		for (x = y; s[x] && !(joe_isalnux(map, s[x]) || s[x] == '.' || s[x] == '/'); ++x)
+			/* nothing */;
 
 		/* Skip to end of first word */
-		for (y = x; joe_isalnum_(map,s[y]) || s[y] == '.' || s[y] == '/'; ++y)
+		for (y = x; joe_isalnux(map, s[y]) || s[y] == '.' || s[y] == '/'; ++y)
 			if (s[y] == '.')
 				flg = 1;
 	} while (!flg && x!=y);
@@ -154,10 +155,15 @@ static int parseit(struct charmap *map,unsigned char *s, long int row)
 	for (y = x; s[y] >= '0' && s[y] <= '9'; ++y) ;
 
 	/* Save line number */
-	if (x != y)
-		sscanf((char *)(s + x), "%ld", &line);
-	if (line != -1)
-		--line;
+	if (x != y) {
+		void *vp;
+
+		line = ustol(s + x, &vp, USTOL_DEC);
+		if (!vp)
+			line = -1;
+		else
+			--line;
+	}
 
 	/* Look for ':' */
 	flg = 0;
@@ -211,15 +217,17 @@ static long parserr(B *b)
 	return nerrs;
 }
 
-BW *find_a_good_bw(B *b)
+static BW *
+find_a_good_bw(B *b)
 {
 	W *w;
 	BW *bw = 0;
 	/* Find lowest window with buffer */
 	if ((w = maint->topwin) != NULL) {
 		do {
-			if ((w->watom->what&TYPETW) && ((BW *)w->object)->b==b && w->y>=0)
-				bw = (BW *)w->object;
+			if ((w->watom->what & TYPETW) &&
+			    w->object.bw->b == b && w->y >= 0)
+				bw = w->object.bw;
 			w = w->link.next;
 		} while (w != maint->topwin);
 	}
@@ -229,7 +237,7 @@ BW *find_a_good_bw(B *b)
 	if ((w = maint->topwin) != NULL) {
 		do {
 			if ((w->watom->what&TYPETW) && w->y>=0)
-				bw = (BW *)w->object;
+				bw = w->object.bw;
 			w = w->link.next;
 		} while (w != maint->topwin);
 	}
@@ -271,14 +279,14 @@ int unxterr(BW *bw)
 	int omid;
 
 	if (errptr->link.next == &errors) {
-		msgnw(bw->parent, US "No more errors");
+		msgnw(bw->parent, UC "No more errors");
 		return -1;
 	}
 	errptr = errptr->link.next;
 	if (!bw->b->name || strcmp(errptr->file, bw->b->name)) {
 		if (doswitch(bw, vsdup(errptr->file), NULL, NULL))
 			return -1;
-		bw = (BW *) maint->curwin->object;
+		bw = maint->curwin->object.bw;
 	}
 	omid = mid;
 	mid = 1;
@@ -296,14 +304,14 @@ int uprverr(BW *bw)
 	int omid;
 
 	if (errptr->link.prev == &errors) {
-		msgnw(bw->parent, US "No more errors");
+		msgnw(bw->parent, UC "No more errors");
 		return -1;
 	}
 	errptr = errptr->link.prev;
 	if (!bw->b->name || strcmp(errptr->file, bw->b->name)) {
 		if (doswitch(bw, vsdup(errptr->file), NULL, NULL))
 			return -1;
-		bw = (BW *) maint->curwin->object;
+		bw = maint->curwin->object.bw;
 	}
 	omid = mid;
 	mid = 1;
