@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/va.c,v 1.3 2012/06/08 16:55:29 tg Exp $ */
 /*
  *	Variable length array of strings
  *	Copyright
@@ -7,54 +6,57 @@
  *	This file is part of JOE (Joe's Own Editor)
  */
 #include "config.h"
+#include "types.h"
+
+__RCSID("$MirOS: contrib/code/jupp/va.c,v 1.10 2018/01/07 20:39:33 tg Exp $");
 
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
 
 #include "utils.h"
 #include "va.h"
 
-aELEMENT *vamk(int len)
+aELEMENT *
+vamk(int len)
 {
-	int *new = (int *) joe_malloc((1 + len) * sizeof(aELEMENT) + 2 * sizeof(int));
+	aELEMENT *rv;
 
-	new[0] = len;
-	new[1] = 0;
-	((aELEMENT *)(new + 2))[0] = aterm;
-	return (aELEMENT *)(new + 2);
+	rv = jalloc(NULL, len, sizeof(aELEMENT));
+	rv[0] = aterm;
+	return (rv);
 }
 
-void varm(aELEMENT *vary)
+void
+varm(aELEMENT *vary)
 {
 	if (vary) {
 		vazap(vary, 0, aLen(vary));
-		joe_free((int *) vary - 2);
+		jfree(vary);
 	}
 }
 
 int alen(aELEMENT *ary)
 {
-	if (ary) {
-		aELEMENT *beg = ary;
-		while (acmp(*ary, aterm))
-			++ary;
-		return ary - beg;
-	} else
-		return 0;
+	aELEMENT *beg = ary;
+
+	if (!ary)
+		return (0);
+
+	while (acmp(*ary, aterm))
+		++ary;
+	return (ary - beg);
 }
 
-aELEMENT *vaensure(aELEMENT *vary, int len)
+aELEMENT *
+vaensure(aELEMENT *vary, int len)
 {
-	if (!vary)
-		vary = vamk(len);
-	else if (len > aSiz(vary)) {
-		len += (len >> 2);
-		vary = (aELEMENT *)(2 + (int *) joe_realloc((int *) vary - 2, (len + 1) * sizeof(aELEMENT) + 2 * sizeof(int)));
+	aELEMENT *rv;
 
-		aSiz(vary) = len;
-	}
-	return vary;
+	if (vary && len > aSiz(vary))
+		len += (len >> 2);
+	rv = jalloc(vary, len, sizeof(aELEMENT));
+	if (!vary)
+		rv[0] = aterm;
+	return (rv);
 }
 
 aELEMENT *vazap(aELEMENT *vary, int pos, int n)
@@ -155,13 +157,15 @@ static int _acmp(aELEMENT *a, aELEMENT *b)
 
 aELEMENT *vasort(aELEMENT *ary, int len)
 {
-	if (!ary || !len)
-		return ary;
-	qsort(ary, len, sizeof(aELEMENT), (int (*)(const void *, const void *))_acmp);
+	if (ary && len)
+		qsort(ary, len, sizeof(aELEMENT),
+		    (int (*)(const void *, const void *))_acmp);
 	return ary;
 }
 
-aELEMENT *vawords(aELEMENT *a, unsigned char *s, int len, unsigned char *sep, int seplen)
+aELEMENT *
+vawords(aELEMENT *a, unsigned char *s, int len,
+    const unsigned char *sep, int seplen)
 {
 	int x;
 
@@ -169,7 +173,7 @@ aELEMENT *vawords(aELEMENT *a, unsigned char *s, int len, unsigned char *sep, in
 		a = vamk(10);
 	else
 		a = vatrunc(a, 0);
-      loop:
+ loop:
 	x = vsspan(s, len, sep, seplen);
 	s += x;
 	len -= x;
