@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/w.h,v 1.4 2017/01/11 22:56:50 tg Exp $ */
 /*
  *	Window management
  *	Copyright
@@ -9,8 +8,9 @@
 #ifndef _JOE_W_H
 #define _JOE_W_H 1
 
-#include "config.h"
-#include "types.h"
+#ifdef EXTERN
+__IDSTRING(rcsid_w_h, "$MirOS: contrib/code/jupp/w.h,v 1.9 2017/12/07 02:10:20 tg Exp $");
+#endif
 
 /***************/
 /* Subroutines */
@@ -19,34 +19,34 @@
 /* int getgrouph(W *);
  * Get height of a family of windows
  */
-int getgrouph PARAMS((W *w));
+int getgrouph(W *w);
 
 /* W *findtopw(W *);
  * Find first (top-most) window of a family
  */
-W *findtopw PARAMS((W *w));
+W *findtopw(W *w);
 
 /* W *findbotw(W *);
  * Find last (bottom-most) window a family
  */
-W *findbotw PARAMS((W *w));
+W *findbotw(W *w);
 
-int demotegroup PARAMS((W *w));
+int demotegroup(W *w);
 
 /* W *lastw(SCREEN *t);
  * Find last window on screen
  */
-W *lastw PARAMS((SCREEN *t));
+W *lastw(SCREEN *t);
 
 /* Determine number of main windows
  */
-int countmain PARAMS((SCREEN *t));
+int countmain(SCREEN *t);
 
 /* void wfit(SCREEN *t);
  *
  * Fit all of the windows onto the screen
  */
-void wfit PARAMS((SCREEN *t));
+void wfit(SCREEN *t);
 
 /*****************/
 /* Main routines */
@@ -56,17 +56,12 @@ void wfit PARAMS((SCREEN *t));
  *
  * Create a screen
  */
-SCREEN *screate PARAMS((SCRN *scrn));
+SCREEN *screate(SCRN *scrn);
 
 /* void sresize(SCREEN *t);
  * Screen size changed
  */
-void sresize PARAMS((SCREEN *t));
-
-/* void chsize(SCREEN *t,int mul,int div)
- * Resize windows: each window is multiplied by the fraction mul/div
- */
-void chsize PARAMS(());
+void sresize(SCREEN *t);
 
 /* W *wcreate(SCREEN *t,WATOM *watom,W *where,W *target,W *original,int height);
  *
@@ -88,87 +83,88 @@ void chsize PARAMS(());
  * Returns the new window or returns 0 if there was not enough space to
  * create the window and maintain family integrity.
  */
-W *wcreate PARAMS((SCREEN *t, WATOM *watom, W *where, W *target, W *original, int height, const unsigned char *huh, int *notify));
+W *wcreate(SCREEN *t, WATOM *watom, W *where, W *target, W *original, int height, const unsigned char *huh, int *notify);
 
 /* int wabort(W *w);
  *
  * Kill a window and it's children
  */
-int wabort PARAMS((W *w));
+int wabort(W *w);
 
 /* int wnext(SCREEN *);
  *
  * Switch to next window
  */
-int wnext PARAMS((SCREEN *t));
+int wnext(SCREEN *t);
 
 /* int wprev(SCREEN *);
  *
  * Switch to previous window
  */
-int wprev PARAMS((SCREEN *t));
+int wprev(SCREEN *t);
 
 /* int wgrow(W *);
  *
  * increase size of window.  Return 0 for success, -1 for fail.
  */
-int wgrow PARAMS((W *w));
+int wgrow(W *w);
 
 /* int wshrink(W *);
  *
  * Decrease size of window.  Returns 0 for success, -1 for fail.
  */
-int wshrink PARAMS((W *w));
+int wshrink(W *w);
 
 /* void wshowone(W *);
  *
  * Show only one window on the screen
  */
-void wshowone PARAMS((W *w));
+void wshowone(W *w);
 
 /* void wshowall(SCREEN *);
  *
  * Show all windows on the screen, including the given one
  */
-void wshowall PARAMS((SCREEN *t));
+void wshowall(SCREEN *t);
 
 /* void wredraw(W *);
  *
  * Force complete redraw of window
  */
-void wredraw PARAMS((W *w));
+void wredraw(W *w);
 
 /* void updall()
  *
  * Redraw all windows
  */
-void updall PARAMS((void));
+void updall(void);
 
 /* void msgnw[t](W *w, char *s);
  * Display a message which will be eliminated on the next keypress.
  * msgnw displays message on bottom line of window
  * msgnwt displays message on top line of window
  */
-void msgnw PARAMS((W *w, const unsigned char *s));
-void msgnwt PARAMS((W *w, const unsigned char *s));
+void msgnw(W *w, const unsigned char *s);
+void msgnwt(W *w, const unsigned char *s);
 
+/* Message composition buffer for msgnw/msgnwt */
 #define JOE_MSGBUFSIZE 300
-extern unsigned char msgbuf[JOE_MSGBUFSIZE];	/* Message composition buffer for msgnw/msgnwt */
+extern unsigned char msgbuf[JOE_MSGBUFSIZE];
 
-void msgout PARAMS((W *w));			/* Output msgnw/msgnwt messages */
+void msgout(W *w);			/* Output msgnw/msgnwt messages */
 
 /* Common user functions */
 
-int urtn PARAMS((BASE *b, int k));		/* User hit return */
-int utype PARAMS((BASE *b, int k));		/* User types a character */
-int uretyp PARAMS((BASE *bw));			/* Refresh the screen */
-int ugroww PARAMS((BASE *bw));			/* Grow current window */
-int uexpld PARAMS((BASE *bw));			/* Explode current window or show all windows */
-int ushrnk PARAMS((BASE *bw));			/* Shrink current window */
-int unextw PARAMS((BASE *bw));			/* Goto next window */
-int uprevw PARAMS((BASE *bw));			/* Goto previous window */
+int urtn(jobject jO, int k);		/* User hit return */
+int utype(jobject jO, int k);		/* User types a character */
+int uretyp(BASE *bw);			/* Refresh the screen */
+int ugroww(BASE *bw);			/* Grow current window */
+int uexpld(BASE *bw);			/* Explode current window or show all windows */
+int ushrnk(BASE *bw);			/* Shrink current window */
+int unextw(BASE *bw);			/* Goto next window */
+int uprevw(BASE *bw);			/* Goto previous window */
 
-void scrdel PARAMS((B *b, long int l, long int n, int flg));
-void scrins PARAMS((B *b, long int l, long int n, int flg));
+void scrdel(B *b, long int l, long int n, int flg);
+void scrins(B *b, long int l, long int n, int flg);
 
 #endif
